@@ -5,7 +5,7 @@ use strict;
 use utf8;
 use 5.010;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use XML::LibXML;
 use XML::Chain::Selector;
@@ -35,6 +35,17 @@ sub xc {
 
     my $self = __PACKAGE__->new();
 
+    my $initial_el = $self->_create_element($el_name_object, undef, @attrs);
+    confess 'document creation must be from single element'
+        unless @$initial_el == 1;
+
+    $self->dom->setDocumentElement($initial_el->[0]->{lxml});
+    return $self->document_element;
+}
+
+sub _create_element {
+    my ($self, $el_name_object, $ns, @attrs) = @_;
+
     if (@attrs == 1) {
         my $hash_attrs = $attrs[0];
         croak 'with two argument second argument must be hashref'
@@ -42,47 +53,47 @@ sub xc {
         @attrs = map { $_ => $hash_attrs->{$_} } sort keys %$hash_attrs;
     }
 
-    my $initial_el;
+    $ns //= {@attrs}->{xmlns} // '';
+
+    my @create_elements;
     if (@attrs) {
-        my $ns_uri = {@attrs}->{xmlns} // '';
-        $initial_el = $self->_create_element($el_name_object, $ns_uri, @attrs);
+        # lxml create
     }
-    elsif (blessed($el_name_object) && $el_name_object->isa('XML::LibXML::Node')) {
-        $initial_el = $self->_xc_el_data($el_name_object);
-        $self->dom->setDocumentElement($initial_el->{lxml});
-        return $self->document_element;
-    }
-    elsif (blessed($el_name_object) && $el_name_object->isa('XML::LibXML::Document')) {
-        $initial_el = $self->_xc_el_data($el_name_object->documentElement);
-        $self->dom($el_name_object);
-        return $self->document_element;
-    }
-    elsif (ref($el_name_object)) {
-        $self->set_io_any($el_name_object);
-        my $dom = XML::LibXML->load_xml(
-            string => IO::Any->slurp($el_name_object),
-        );
-        $initial_el = $self->_xc_el_data($dom->documentElement);
-        $self->dom($dom);
-        return $self->document_element;
+    if (ref($el_name_object)) {
+        if (blessed($el_name_object)) {
+            if ($el_name_object->isa('XML::Chain::Selector')) {
+                @create_elements = @{$el_name_object->current_elements};
+            }
+            if ($el_name_object->isa('XML::LibXML::Node')) {
+                @create_elements = $self->_xc_el_data($el_name_object);
+            }
+            elsif ($el_name_object->isa('XML::LibXML::Document')) {
+                @create_elements = $self->_xc_el_data($el_name_object->documentElement);
+            }
+        }
+
+        unless (@create_elements) {
+            $self->{io_any} = $el_name_object;
+            my $dom = XML::LibXML->load_xml(
+                string => IO::Any->slurp($el_name_object),
+            );
+            @create_elements = $self->_xc_el_data($dom->documentElement);
+        }
     }
     else {
-        $initial_el = $self->_create_element($el_name_object, '');
+        # lxml create
     }
 
-    $self->dom->setDocumentElement($initial_el->{lxml});
-    return $self->document_element;
-}
-
-sub _create_element {
-    my ($self, $el_name, $ns, @attrs) = @_;
-
-    my $new_element = $self->dom->createElementNS($ns, $el_name);
-    while (my $attr_name = shift(@attrs)) {
-        my $attr_value = shift(@attrs);
-        $new_element->setAttribute($attr_name => $attr_value);
+    unless (@create_elements) {
+        my $new_element = $self->dom->createElementNS($ns, $el_name_object);
+        while (my $attr_name = shift(@attrs)) {
+            my $attr_value = shift(@attrs);
+            $new_element->setAttribute($attr_name => $attr_value);
+        }
+        @create_elements = $self->_xc_el_data($new_element);
     }
-    return $self->_xc_el_data($new_element);
+
+    return \@create_elements;
 }
 
 sub _xc_el_data {
@@ -91,8 +102,9 @@ sub _xc_el_data {
 
     my $eid = $el->unique_key;
     return $self->{_xc_el_data}->{$eid} //= {
-        ns => $el->namespaceURI // '',
+        eid  => $eid,
         lxml => $el,
+        ns   => ($el->namespaceURI // ''),
     };
 }
 
@@ -115,13 +127,13 @@ sub store {
     my $io_any = $self->{io_any};
     croak 'io_any was not set' unless $io_any;
     IO::Any->spew($io_any, $self->document_element->as_string, {atomic => 1});
-    return $self;
+    return $self->document_element;
 }
 
 sub set_io_any {
     my ($self, $to_set) = @_;
     $self->{io_any} = $to_set;
-    return $self;
+    return $self->document_element;
 }
 
 1;
@@ -142,9 +154,11 @@ XML::Chain - chained way of manipulating and inspecting XML documents
     my $div = xc('div', class => 'pretty')
                 ->c('h1')->t('hello')
                 ->up
-                ->c('p', class => 'intro')->t('world!');
+                ->c('p', class => 'intro')->t('world')
+                ->root
+                ->a( xc('p')->t('of chained XML.') );
     say $div->as_string;
-    # <div class="pretty"><h1>hello</h1><p class="intro">world!</p></div>
+    # <div class="pretty"><h1>hello</h1><p class="intro">world</p><p>of chained XML.</p></div>
 
 =head1 DESCRIPTION
 
@@ -201,10 +215,10 @@ See L<XML::Chain::Selector> and L<XML::Chain::Element>.
 =head1 CHAINED DOCUMENT METHODS
 
     xc('body')->t('save me')->set_io_any([$tmp_dir, 't01.xml'])->store;
-    # $tmp_dir/t01.xml file no consists of:
+    # $tmp_dir/t01.xml file now consists of:
         <body>save me</body>
     xc([$tmp_dir, 't01.xml'])->empty->c('div')->t('updated')->store;
-    # $tmp_dir/t01.xml file no consists of:
+    # $tmp_dir/t01.xml file now consists of:
         <body><div>updated</div></body>
 
 =head2 set_io_any
@@ -221,6 +235,7 @@ C<set_io_any>.
 
     - partial/special tidy (on elements inside xml)
     - per ->data() storage
+    - ->each(sub {...}) / ->map(sub {}) / ->grep(sub {})
     - setting and handling namespaces and elements with ns prefixes
     - ~ton of selectors and manipulators to be added
 
